from __future__ import unicode_literals
from . import common
from Plugins.Extensions.setupGlass17.auth.client import Client, SIGNATURE_HMAC, SIGNATURE_TYPE_AUTH_HEADER, SIGNATURE_TYPE_BODY
from requests.utils import to_native_string
from requests.auth import AuthBase
from secrets import randbelow
import sys
PY3 = sys.version_info[0] == 3
if PY3:
    unicode_type = str
else:
    unicode_type = unicode
CONTENT_TYPE_FORM_URLENCODED = u'application/x-www-form-urlencoded'
CONTENT_TYPE_MULTI_PART = u'multipart/form-data'

class OAuth1(AuthBase):
    u"""Signs the request using OAuth 1 (RFC5849)"""
    client_class = Client

    def __init__(self, client_key, client_secret = None, resource_owner_key = None, resource_owner_secret = None, callback_uri = None, signature_method = SIGNATURE_HMAC, signature_type = SIGNATURE_TYPE_AUTH_HEADER, rsa_key = None, verifier = None, decoding = u'utf-8', client_class = None, force_include_body = False, **kwargs):
        try:
            signature_type = signature_type.upper()
        except AttributeError:
            pass

        client_class = client_class or self.client_class
        self.force_include_body = force_include_body
        self.client = client_class(client_key, client_secret, resource_owner_key, resource_owner_secret, callback_uri, signature_method, signature_type, rsa_key, verifier, decoding=decoding, **kwargs)

    def __call__(self, r):
        u"""Add OAuth parameters to the request.
        
        Parameters may be included from the body if the content-type is
        urlencoded, if no content type is set a guess is made.
        """
        content_type = r.headers.get(u'Content-Type', u'')
        if not content_type and common.extract_params(r.body) or self.client.signature_type == SIGNATURE_TYPE_BODY:
            content_type = CONTENT_TYPE_FORM_URLENCODED
        if not isinstance(content_type, unicode_type):
            content_type = content_type.decode(u'utf-8')
        is_form_encoded = CONTENT_TYPE_FORM_URLENCODED in content_type
        if is_form_encoded:
            r.headers[u'Content-Type'] = CONTENT_TYPE_FORM_URLENCODED
            r.url, headers, r.body = self.client.sign(unicode_type(r.url), unicode_type(r.method), r.body or u'', r.headers)
        elif self.force_include_body:
            r.url, headers, r.body = self.client.sign(unicode_type(r.url), unicode_type(r.method), r.body or u'', r.headers)
        else:
            r.url, headers, _ = self.client.sign(unicode_type(r.url), unicode_type(r.method), None, r.headers)
        r.prepare_headers(headers)
        r.url = to_native_string(r.url)
        return r


def Auth():
    appkeys = [(u'dj0yJmk9bXBWenQxUHNtY3R1JnM9Y29uc3VtZXJzZWNyZXQmc3Y9MCZ4PWZl', u'3d5a2ae2ac13ac15d34b004b613aaeb5fd2efb7e'), (u'dj0yJmk9Z3pEQURaeHlab1NPJnM9Y29uc3VtZXJzZWNyZXQmc3Y9MCZ4PWYz', u'6c8e7504cf91e73d4dc576867234e0af31d7c635')]
    key = randbelow(2)
    return OAuth1(appkeys[key][0], appkeys[key][1], signature_type=u'query')